is_cap_hall_witness

Function is_cap_hall_witness 

pub fn is_cap_hall_witness(
    adj: &[Vec<usize>],
    capacities: &[usize],
    w: &CapHallWitness,
) -> bool
Re-check a capacitated Hall witness: every item in S reaches only slots in T, and the total capacity of T is below |S|.